summaryrefslogtreecommitdiffstats
path: root/kopete/libkopete/kopetechatsession.h
diff options
context:
space:
mode:
Diffstat (limited to 'kopete/libkopete/kopetechatsession.h')
-rw-r--r--kopete/libkopete/kopetechatsession.h8
1 files changed, 4 insertions, 4 deletions
diff --git a/kopete/libkopete/kopetechatsession.h b/kopete/libkopete/kopetechatsession.h
index 802a4e39..cab992c9 100644
--- a/kopete/libkopete/kopetechatsession.h
+++ b/kopete/libkopete/kopetechatsession.h
@@ -130,7 +130,7 @@ public:
* Set a special icon for a contact in this kmm only.
* by default, all contact have their own status
*/
- void setContactOnlineStatus( const Contact *contact, const OnlineStatus &newtqStatus );
+ void setContactOnlineStatus( const Contact *contact, const OnlineStatus &newStatus );
/**
* @brief get the status of a contact.
@@ -296,13 +296,13 @@ public slots:
/**
* Add a contact to the session with a pre-set initial status
* @param c is the contact
* @param initialtqStatus The initial contactOnlineStatus of the contact
* @param suppress mean the there will be no automatic notifications in the chatwindow.
* (note that i don't like the param suppress at all. it is used in irc to show a different notification (with an info text)
* a TQStringinfo would be more interesting, but it is also used to don't show the notification when entering in a channel)
* @see contactOnlineStatus
*/
- void addContact( const Kopete::Contact *c, const Kopete::OnlineStatus &initialtqStatus, bool suppress = false );
+ void addContact( const Kopete::Contact *c, const Kopete::OnlineStatus &initialStatus, bool suppress = false );
/**
* Remove a contact from the session
@@ -371,7 +371,7 @@ public slots:
private slots:
void slotUpdateDisplayName();
void slotViewDestroyed();
- void slotOnlineStatusChanged( Kopete::Contact *c, const Kopete::OnlineStatus &status, const Kopete::OnlineStatus &oldtqStatus );
+ void slotOnlineStatusChanged( Kopete::Contact *c, const Kopete::OnlineStatus &status, const Kopete::OnlineStatus &oldStatus );
void slotContactDestroyed( Kopete::Contact *contact );
protected:
@@ -296,13 +296,13 @@ public slots:
* Add a contact to the session with a pre-set initial status
* @param c is the contact
- * @param initialtqStatus The initial contactOnlineStatus of the contact
+ * @param initialStatus The initial contactOnlineStatus of the contact
* @param suppress mean the there will be no automatic notifications in the chatwindow.
* (note that i don't like the param suppress at all. it is used in irc to show a different notification (with an info text)